(define-module (ui ldap-groups ajax)
    :use-module (alterator woo)
    :use-module (alterator ajax)
    :export (init))

;;; members

(define (update-member-list . data)
    (let ((group (if (pair? data) (car data) (form-value "group"))))
      (form-update-enum "member_in" (woo "member_list_in" "/ldap-groups" 'group group))
      (form-update-enum "member_out" (woo "member_list_out" "/ldap-groups" 'group group))))

(define (ui-member-add)
  (let ((group (form-value "group"))
        (member_out (form-value "member_out")))
    (and (string? group) (string? member_out)
	 (catch/message
	   (lambda()
	     (woo "member_add"
	      "/ldap-groups"
		  'language (form-value "language")
		  'group group
		  'member_out member_out)
	     (update-member-list (form-value "group")))))))

(define (ui-member-del)
  (let ((group (form-value "group"))
        (member_in (form-value "member_in")))
    (and (string? group) (string? member_in)
	 (catch/message
	   (lambda()
	     (woo "member_del"
	       "/ldap-groups"
		  'language (form-value "language")
		  'group group
		  'member_in member_in)
	     (update-member-list (form-value "group")))))))

;;; emails

(define (update-email-list . data)
    (let ((group (if (pair? data) (car data) (form-value "group"))))
      (form-update-enum "email" (woo "email_list" "/ldap-groups" 'group group))))

(define (ui-email-add)
  (let ((group (form-value "group"))
        (new_email (form-value "new_email")))
    (and (string? group) (string? new_email)
	 (catch/message
	   (lambda()
	     (woo "email_add"
	      "/ldap-groups"
		  'language (form-value "language")
		  'group group
		  'new_email new_email)
	     (form-update-value "new_email" "")
	     (update-email-list (form-value "group")))))))

(define (ui-email-del)
  (let ((group (form-value "group"))
        (email (form-value "email")))
    (and (string? group) (string? email)
	 (catch/message
	   (lambda()
	     (woo "email_del"
	      "/ldap-groups"
		  'language (form-value "language")
		  'group group
		  'email email)
	     (update-email-list (form-value "group")))))))

;;; groups

(define (update-groups . data)
  (let ((group (if (pair? data) (car data) (form-value "group"))))
    (if (not (string-contains group ";"))
      (begin
        (form-update-visibility "update_message" #f)
	(form-update-value "group_name" group)
	(woo "member_reset" "/ldap-groups" 'group group)
	(woo "email_reset" "/ldap-groups" 'group group)
	(update-member-list group)
	(update-email-list group)))))

(define (ui-group-del)
  (let ((group (form-value "group")))
    (and (string? group)
	 (catch/message
	   (lambda()
	     (woo-delete "/ldap-groups" 'group group 'language (form-value "language"))
	     (ui-init))))))

(define (ui-group-add)
  (let ((new_group (form-value "new_group")))
    (and (string? new_group)
	 (catch/message
	   (lambda()
	     (woo-new "/ldap-groups" 'new_group new_group 'language (form-value "language"))
	     (ui-init)
	     (form-update-value "group" new_group)
	     (update-groups new_group))))))

(define (ui-group-save)
  (let ((group (form-value "group")))
    (and (string? group)
	 (catch/message
	   (lambda()
	     (form-update-visibility "update_message" #f)
	     (woo "member_commit"
	      "/ldap-groups"
		  'language (form-value "language")
		  'group group)
	     (woo "email_commit"
	      "/ldap-groups"
		  'language (form-value "language")
		  'group group)
	    (update-groups group)
	    (form-update-visibility "update_message" #t))))))

(define (ui-init)
    (form-update-value "new_group" "")
    (form-update-value "group_name" "")
    (form-update-enum "member_in" '())
    (form-update-enum "member_out" '())
    (form-update-value "new_email" "")
    (form-update-visibility "update_message" #f)
    (form-update-enum "group" (woo-list "/ldap-groups")))

(define (init)
    (ui-init)
    (form-bind "group" "change" update-groups)
    (form-bind "member_add_button" "click" ui-member-add)
    (form-bind "member_del_button" "click" ui-member-del)

    (form-bind "email_add_button" "click" ui-email-add)
    (form-bind "email_del_button" "click" ui-email-del)

    (form-bind "group_save_button" "click" ui-group-save)
    (form-bind "group_del_button" "click" ui-group-del)
    (form-bind "group_add_button" "click" ui-group-add))
